==> nextcloud-20.0.12.tgz: nextcloud/apps/oauth2/l10n/mk.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Вашиот клиент не е авторизиран за да се поврзе. Ве молиме, информирајте администратор за вашиот клиент.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Вашето УРЛ со пренасочување треба да биде целосно УРЛ:\nhttps://vasdomen.com/pateka",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Дозволи OAuth2 компатибилна автентификација од други веб апликации.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "OAuth2 апликацијата им овозможува на администраторите да конфигурираат вграден проток за автентификација, истотака дозволува OAuth2 компатибилна автентификација од други веб апликации.",
    "OAuth 2.0 clients" : "OAuth 2.0 клиенти",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 овозможува на надворешни сервиси да побараат пристап на {instanceName}.",
    "Add client" : "Додади клиент",
    "Name" : "Име",
    "Redirection URI" : "Пренасочено URI",
    "Add" : "Додади",
    "Client Identifier" : "Идентификатор на клиент",
    "Secret" : "Тајна",
    "Show client secret" : "Прикажи тајна на клиент",
    "Delete" : "Избриши"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> nextcloud-27.1.5.tgz: nextcloud/apps/oauth2/l10n/mk.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Вашиот клиент не е авторизиран за да се поврзе. Ве молиме, информирајте администратор за вашиот клиент.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Вашето УРЛ со пренасочување треба да биде целосно УРЛ:\nhttps://vasdomen.com/pateka",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Дозволи OAuth2 компатибилна автентификација од други веб апликации.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "OAuth2 апликацијата им овозможува на администраторите да конфигурираат вграден проток за автентификација, истотака дозволува OAuth2 компатибилна автентификација од други веб апликации.",
    "OAuth 2.0 clients" : "OAuth 2.0 клиенти",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 овозможува на надворешни сервиси да побараат пристап на {instanceName}.",
    "Name" : "Име",
    "Redirection URI" : "Пренасочено URI",
    "Client Identifier" : "Идентификатор на клиент",
    "Secret key" : "Таен клуч",
    "Add client" : "Додади клиент",
    "Add" : "Додади",
    "Show client secret" : "Прикажи тајна на клиент",
    "Delete" : "Избриши",
    "Secret" : "Тајна"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
